@@ -1,5 +1,9 @@
 from psutil import pid_exists
 import re
+import time
+
+from mjworker.variables import sync_pidfile, pid_files
+from mjworker.public import write_pid
 
 def check_process_status(pid_check_list):
     failed_process = []
@@ -20,4 +24,10 @@ def sync_status(pid_check_list):
         print('process check successful')
     else:
         print(failed_process, 'process check error')
-    
\ No newline at end of file
+
+def sync_runner(master_data):
+    write_pid(sync_pidfile)
+    time.sleep(2)
+    while True:
+        sync_status(pid_files)
+        time.sleep(10)
\ No newline at end of file
