@@ -7,9 +7,8 @@ try:
 except ImportError:
     from urlparse import urljoin
 
-from mjworker.variables import pid_files, sync_pidfile
-from mjworker.sync import sync_status
-from mjworker.public import write_pid
+from mjworker.variables import sync_pidfile
+from mjworker.sync import sync_runner
 from mjworker.publish import publish_runner
 from mjworker.task import task_runner
 
@@ -53,13 +52,13 @@ def run(server, workerid, sessionid, timeout):
     master_data = {"server": server, "workerId": workerid, "sessionId": sessionid, "timeout": timeout}
     task_process = Process(target=task_runner, args=(master_data,))
     publish_process = Process(target=publish_runner, args=(master_data,))
+    sync_process = Process(target=sync_runner, args=(master_data,))
     task_process.start()
     publish_process.start()
-    write_pid(current_process().pid, sync_pidfile)
-    time.sleep(2)
-    while True:
-        sync_status(pid_files)
-        time.sleep(10)
+    sync_process.start()
+    sync_process.join()
+    publish_process.join()
+    publish_process.join()
 
 cli.add_command(register)
 cli.add_command(run)
